/*
 * Project       : ipv6calc
 * File          : dbieee_oui36.h
 * Version       : $Id: dbieee_oui36.h,v 1.15 2014/07/14 06:20:02 ds6peter Exp $
 * Generated     : Mon Jul 14 08:12:47 2014
 * Data copyright: IEEE
 *
 * Information:
 *  Additional header file for libipv6calc_db_wrapper_BuiltIn.c
 */

/*@unused@*/ static const char* libieee_oui36_status __attribute__ ((__unused__)) = "OUI36/20140714";


static const s_ieee_oui36 libieee_oui36[] = {
	{ 0x001BC5, 0x000000, 0x000FFF, "Converging Systems Inc.", "CONVERGING" },
	{ 0x001BC5, 0x001000, 0x001FFF, "OpenRB.com, Direct SIA", "OPENRB-COM-DIRECT-SIA" },
	{ 0x001BC5, 0x002000, 0x002FFF, "GORAMO - Janusz Gorecki", "GORAMO---JANUSZ-GORECKI" },
	{ 0x001BC5, 0x003000, 0x003FFF, "MicroSigns Technologies Inc", "MICROSIGNS-TECHNOLOGIES" },
	{ 0x001BC5, 0x004000, 0x004FFF, "Intellvisions Software Ltd", "INTELLVISIONS-SOFTWARE" },
	{ 0x001BC5, 0x005000, 0x005FFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x006000, 0x006FFF, "TRIAX-HIRSCHMANN Multi-Media GmbH", "TRIAX-HIRSCHMANN-MULTI-MEDIA" },
	{ 0x001BC5, 0x007000, 0x007FFF, "Energy Aware Technology", "ENERGY-AWARE" },
	{ 0x001BC5, 0x008000, 0x008FFF, "Dalaj Electro-Telecom", "DALAJ-ELECTRO-TELECOM" },
	{ 0x001BC5, 0x009000, 0x009FFF, "Solomon Systech Pte Ltd", "SOLOMON-SYSTECH-PTE" },
	{ 0x001BC5, 0x00A000, 0x00AFFF, "Mercury HMI Ltd", "MERCURY-HMI" },
	{ 0x001BC5, 0x00B000, 0x00BFFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x00C000, 0x00CFFF, "Quantum Technology Sciences, Inc.", "QUANTUM-SCIENCES" },
	{ 0x001BC5, 0x00D000, 0x00DFFF, "Advanced Scientific Concepts, Inc.", "ADVANCED-SCIENTIFIC-CONCEPTS" },
	{ 0x001BC5, 0x00E000, 0x00EFFF, "Vigor Electric Corp", "VIGOR-ELECTRIC" },
	{ 0x001BC5, 0x00F000, 0x00FFFF, "Simavita Pty Ltd", "SIMAVITA-PTY" },
	{ 0x001BC5, 0x010000, 0x010FFF, "Softel SA de CV", "SOFTEL-DE-CV" },
	{ 0x001BC5, 0x011000, 0x011FFF, "OOO NPP Mera", "OOO-NPP-MERA" },
	{ 0x001BC5, 0x012000, 0x012FFF, "Tokyo Cosmos Electric, Inc.", "TOKYO-COSMOS-ELECTRIC" },
	{ 0x001BC5, 0x013000, 0x013FFF, "Zamir Recognition Systems Ltd.", "ZAMIR-RECOGNITION" },
	{ 0x001BC5, 0x014000, 0x014FFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x015000, 0x015FFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x016000, 0x016FFF, "Energotechnica OOO NPP Ltd", "ENERGOTECHNICA-OOO-NPP" },
	{ 0x001BC5, 0x017000, 0x017FFF, "cPacket Networks", "CPACKET-NETWORKS" },
	{ 0x001BC5, 0x019000, 0x019FFF, "Dunlop Systems & Components", "DUNLOP-COMPONENTS" },
	{ 0x001BC5, 0x01A000, 0x01AFFF, "ABA ELECTRONICS TECHNOLOGY CO.,LTD", "ABA-ELECTRONICS" },
	{ 0x001BC5, 0x01B000, 0x01BFFF, "Commonwealth Scientific and Industrial Research Organisation", "COMMONWEALTH-SCIENTIFIC-AND-INDUSTRIAL-RESEARCH-ORGANISATION" },
	{ 0x001BC5, 0x01C000, 0x01CFFF, "Coolit Systems, Inc.", "COOLIT" },
	{ 0x001BC5, 0x01D000, 0x01DFFF, "Rose + Herleth GbR", "ROSE-+-HERLETH-GBR" },
	{ 0x001BC5, 0x01E000, 0x01EFFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x01F000, 0x01FFFF, "Saturn Solutions Ltd", "SATURN-SOLUTIONS" },
	{ 0x001BC5, 0x020000, 0x020FFF, "Momentum Data Systems", "MOMENTUM-DATA" },
	{ 0x001BC5, 0x021000, 0x021FFF, "Openpeak, Inc", "OPENPEAK" },
	{ 0x001BC5, 0x022000, 0x022FFF, "CJSC STC SIMOS", "CJSC-STC-SIMOS" },
	{ 0x001BC5, 0x023000, 0x023FFF, "MAGO di Della Mora Walter", "MAGO-DI-DELLA-MORA-WALTER" },
	{ 0x001BC5, 0x024000, 0x024FFF, "ANNECY ELECTRONIQUE SAS", "ANNECY-ELECTRONIQUE-SAS" },
	{ 0x001BC5, 0x025000, 0x025FFF, "andersen lighting GmbH", "ANDERSEN-LIGHTING" },
	{ 0x001BC5, 0x026000, 0x026FFF, "DIMEP Sistemas", "DIMEP-SISTEMAS" },
	{ 0x001BC5, 0x027000, 0x027FFF, "CAMEA, spol. s r.o.", "CAMEA-SPOL-S-R-O" },
	{ 0x001BC5, 0x028000, 0x028FFF, "STECHWIN.CO.LTD.", "STECHWIN" },
	{ 0x001BC5, 0x029000, 0x029FFF, "2 FRANCE MARINE", "2-FRANCE-MARINE" },
	{ 0x001BC5, 0x02A000, 0x02AFFF, "Analytical Instrument Systems, Inc.", "ANALYTICAL-INSTRUMENT" },
	{ 0x001BC5, 0x02B000, 0x02BFFF, "Saturn South Pty Ltd", "SATURN-SOUTH-PTY" },
	{ 0x001BC5, 0x02C000, 0x02CFFF, "Care Everywhere LLC", "CARE-EVERYWHERE-LLC" },
	{ 0x001BC5, 0x02D000, 0x02DFFF, "DDTRONIK Dariusz Dowgiert", "DDTRONIK-DARIUSZ-DOWGIERT" },
	{ 0x001BC5, 0x02E000, 0x02EFFF, "BETTINI SRL", "BETTINI-SRL" },
	{ 0x001BC5, 0x02F000, 0x02FFFF, "Fibrain Co. Ltd.", "FIBRAIN" },
	{ 0x001BC5, 0x030000, 0x030FFF, "OctoGate it Security Systems GmbH", "OCTOGATE-IT-SECURITY" },
	{ 0x001BC5, 0x031000, 0x031FFF, "ADIXEIN LIMITED", "ADIXEIN" },
	{ 0x001BC5, 0x032000, 0x032FFF, "Osborne Coinage Co", "OSBORNE-COINAGE" },
	{ 0x001BC5, 0x033000, 0x033FFF, "JE Suunnittelu Oy", "JE-SUUNNITTELU-OY" },
	{ 0x001BC5, 0x034000, 0x034FFF, "InterCEL Pty Ltd", "INTERCEL-PTY" },
	{ 0x001BC5, 0x035000, 0x035FFF, "RTLS Ltd.", "RTLS" },
	{ 0x001BC5, 0x036000, 0x036FFF, "LOMAR SRL", "LOMAR-SRL" },
	{ 0x001BC5, 0x037000, 0x037FFF, "ITW Reyflex North America", "ITW-REYFLEX-NORTH-AMERICA" },
	{ 0x001BC5, 0x038000, 0x038FFF, "SEED International Ltd.", "SEED" },
	{ 0x001BC5, 0x039000, 0x039FFF, "EURESYS S.A.", "EURESYS" },
	{ 0x001BC5, 0x03A000, 0x03AFFF, "MindMade Sp. z o.o.", "MINDMADE-SP-Z-O-O" },
	{ 0x001BC5, 0x03B000, 0x03BFFF, "Promixis, LLC", "PROMIXIS-LLC" },
	{ 0x001BC5, 0x03C000, 0x03CFFF, "Xiphos Systems Corp.", "XIPHOS" },
	{ 0x001BC5, 0x03D000, 0x03DFFF, "rioxo GmbH", "RIOXO" },
	{ 0x001BC5, 0x03E000, 0x03EFFF, "Daylight Solutions, Inc", "DAYLIGHT-SOLUTIONS" },
	{ 0x001BC5, 0x03F000, 0x03FFFF, "ELTRADE Ltd", "ELTRADE" },
	{ 0x001BC5, 0x040000, 0x040FFF, "OOO Actidata", "OOO-ACTIDATA" },
	{ 0x001BC5, 0x041000, 0x041FFF, "DesignA Electronics Limited", "DESIGNA-ELECTRONICS" },
	{ 0x001BC5, 0x042000, 0x042FFF, "ChamSys Limited", "CHAMSYS" },
	{ 0x001BC5, 0x043000, 0x043FFF, "Coincident, Inc.", "COINCIDENT" },
	{ 0x001BC5, 0x044000, 0x044FFF, "ZAO &quot;RADIUS Avtomatika&quot;", "ZAO-QUOT-RADIUS-AVTOMATIKA-QUOT" },
	{ 0x001BC5, 0x045000, 0x045FFF, "Marvel Digital International Limited", "MARVEL-DIGITAL" },
	{ 0x001BC5, 0x046000, 0x046FFF, "Trans-European Research and Education Networking Association (TERENA)", "TRANS-EUROPEAN-RESEARCH-AND-EDUCATION-NETWORKING-ASSOCIATION-TERENA" },
	{ 0x001BC5, 0x047000, 0x047FFF, "PT. Amanindo Nusapadu", "PT-AMANINDO-NUSAPADU" },
	{ 0x001BC5, 0x048000, 0x048FFF, "XPossible Technologies Pte Ltd", "XPOSSIBLE-TECHNOLOGIES-PTE" },
	{ 0x001BC5, 0x049000, 0x049FFF, "EUROCONTROL S.p.A.", "EUROCONTROL-S-P-A" },
	{ 0x001BC5, 0x04A000, 0x04AFFF, "Certis Technology International Pte Ltd", "CERTIS-PTE" },
	{ 0x001BC5, 0x04B000, 0x04BFFF, "Silicon Controls", "SILICON-CONTROLS" },
	{ 0x001BC5, 0x04C000, 0x04CFFF, "Rhino Controls Ltd.", "RHINO-CONTROLS" },
	{ 0x001BC5, 0x04D000, 0x04DFFF, "eiraku electric corp.", "EIRAKU-ELECTRIC" },
	{ 0x001BC5, 0x04E000, 0x04EFFF, "Messung Systems", "MESSUNG" },
	{ 0x001BC5, 0x04F000, 0x04FFFF, "Orbital Systems, Ltd.", "ORBITAL" },
	{ 0x001BC5, 0x050000, 0x050FFF, "TeliSwitch Solutions", "TELISWITCH-SOLUTIONS" },
	{ 0x001BC5, 0x051000, 0x051FFF, "QQ Navigation AB", "QQ-NAVIGATION-AB" },
	{ 0x001BC5, 0x052000, 0x052FFF, "Engineering Center ENERGOSERVICE", "ENGINEERING-CENTER-ENERGOSERVICE" },
	{ 0x001BC5, 0x053000, 0x053FFF, "Metrycom Communications Ltd", "METRYCOM-COMMUNICATION" },
	{ 0x001BC5, 0x054000, 0x054FFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x055000, 0x055FFF, "LUMIPLAN TRANSPORT", "LUMIPLAN-TRANSPORT" },
	{ 0x001BC5, 0x056000, 0x056FFF, "ThinKom Solutions, Inc", "THINKOM-SOLUTIONS" },
	{ 0x001BC5, 0x057000, 0x057FFF, "EREE Electronique", "EREE-ELECTRONIQUE" },
	{ 0x001BC5, 0x058000, 0x058FFF, "optiMEAS GmbH", "OPTIMEAS" },
	{ 0x001BC5, 0x059000, 0x059FFF, "INPIXAL", "INPIXAL" },
	{ 0x001BC5, 0x05A000, 0x05AFFF, "POSTEC DATA SYSTEMS", "POSTEC-DATA" },
	{ 0x001BC5, 0x05B000, 0x05BFFF, "konzeptpark GmbH", "KONZEPTPARK" },
	{ 0x001BC5, 0x05C000, 0x05CFFF, "Suretrak Global Pty Ltd", "SURETRAK-GLOBAL-PTY" },
	{ 0x001BC5, 0x05D000, 0x05DFFF, "JSC Prominform", "JSC-PROMINFORM" },
	{ 0x001BC5, 0x05E000, 0x05EFFF, "Ecomed-Complex", "ECOMED-COMPLEX" },
	{ 0x001BC5, 0x05F000, 0x05FFFF, "Klingenthaler Musikelektronik GmbH", "KLINGENTHALER-MUSIKELEKTRONIK" },
	{ 0x001BC5, 0x060000, 0x060FFF, "ENSTECH", "ENSTECH" },
	{ 0x001BC5, 0x061000, 0x061FFF, "Scientific-Technical Center Epsilon Limited company", "SCIENTIFIC-TECHNICAL-CENTER-EPSILON-COMPANY" },
	{ 0x001BC5, 0x062000, 0x062FFF, "Sulaon Oy", "SULAON-OY" },
	{ 0x001BC5, 0x063000, 0x063FFF, "Check-It Solutions Inc", "CHECK-IT-SOLUTIONS" },
	{ 0x001BC5, 0x064000, 0x064FFF, "Enkora Oy Ltd", "ENKORA-OY" },
	{ 0x001BC5, 0x065000, 0x065FFF, "Plair Media Inc.", "PLAIR-MEDIA" },
	{ 0x001BC5, 0x066000, 0x066FFF, "Manufacturas y transformados AB", "MANUFACTURAS-Y-TRANSFORMADOS-AB" },
	{ 0x001BC5, 0x067000, 0x067FFF, "Embit srl", "EMBIT-SRL" },
	{ 0x001BC5, 0x068000, 0x068FFF, "HCS KABLOLAMA SISTEMLERI SAN. ve TIC.A.S.", "HCS-KABLOLAMA-SISTEMLERI-SAN-VE-TIC-A-S" },
	{ 0x001BC5, 0x069000, 0x069FFF, "Datasat Digital Entertainment", "DATASAT-DIGITAL-ENTERTAINMENT" },
	{ 0x001BC5, 0x06A000, 0x06AFFF, "IST GmbH", "IST" },
	{ 0x001BC5, 0x06B000, 0x06BFFF, "Verified Energy, LLC.", "VERIFIED-ENERGY-LLC" },
	{ 0x001BC5, 0x06C000, 0x06CFFF, "Luxcon System Limited", "LUXCON-SYSTEM" },
	{ 0x001BC5, 0x06D000, 0x06DFFF, "TES Electronic Solutions (I) Pvt. Ltd.", "TES-SOLUTIONS-I-PVT" },
	{ 0x001BC5, 0x06E000, 0x06EFFF, "Two Dimensional Instruments, LLC", "TWO-DIMENSIONAL-INSTRUMENTS-LLC" },
	{ 0x001BC5, 0x06F000, 0x06FFFF, "LLC Emzior", "LLC-EMZIOR" },
	{ 0x001BC5, 0x070000, 0x070FFF, "Siemens Industries, Inc, Retail & Commercial Systems", "SIEMENS-INDUSTRIES-RETAIL-COMMERCIAL" },
	{ 0x001BC5, 0x071000, 0x071FFF, "Center for E-Commerce Infrastructure Development, The University of Hong Kong", "CENTER-FOR-E-COMMERCE-INFRASTRUCTURE-DEVELOPMENT-THE-UNIVERSITY-OF-HONG-KONG" },
	{ 0x001BC5, 0x072000, 0x072FFF, "Ohio Semitronics, Inc.", "OHIO-SEMITRONICS" },
	{ 0x001BC5, 0x073000, 0x073FFF, "tado GmbH", "TADO" },
	{ 0x001BC5, 0x074000, 0x074FFF, "Dynasthetics", "DYNASTHETICS" },
	{ 0x001BC5, 0x075000, 0x075FFF, "Kitron GmbH", "KITRON" },
	{ 0x001BC5, 0x076000, 0x076FFF, "PLAiR Media, Inc", "PLAIR-MEDIA" },
	{ 0x001BC5, 0x077000, 0x077FFF, "Momentum Data Systems", "MOMENTUM-DATA" },
	{ 0x001BC5, 0x078000, 0x078FFF, "Donbass Soft Ltd and Co.KG", "DONBASS-SOFT-AND" },
	{ 0x001BC5, 0x079000, 0x079FFF, "HPI High Pressure Instrumentation GmbH", "HPI-HIGH-PRESSURE-INSTRUMENTATION" },
	{ 0x001BC5, 0x07A000, 0x07AFFF, "Servicios Electronicos Industriales Berbel s.l.", "SERVICIOS-ELECTRONICOS-INDUSTRIALES-BERBEL-S-L" },
	{ 0x001BC5, 0x07B000, 0x07BFFF, "QCORE Medical", "QCORE-MEDICAL" },
	{ 0x001BC5, 0x07C000, 0x07CFFF, "Head", "HEAD" },
	{ 0x001BC5, 0x07D000, 0x07DFFF, "Greatcom AG", "GREATCOM" },
	{ 0x001BC5, 0x07E000, 0x07EFFF, "Bio Molecular System Pty Ltd", "BIO-MOLECULAR-SYSTEM-PTY" },
	{ 0x001BC5, 0x07F000, 0x07FFFF, "Hitechlab Inc", "HITECHLAB" },
	{ 0x001BC5, 0x080000, 0x080FFF, "LUMINO GmbH", "LUMINO" },
	{ 0x001BC5, 0x081000, 0x081FFF, "WonATech Co., Ltd.", "WONATECH" },
	{ 0x001BC5, 0x082000, 0x082FFF, "TGS Geophysical Company (UK) Limited", "TGS-GEOPHYSICAL-COMPANY-UK" },
	{ 0x001BC5, 0x083000, 0x083FFF, "DIWEL", "DIWEL" },
	{ 0x001BC5, 0x084000, 0x084FFF, "Applied Innovations Research LLC", "APPLIED-INNOVATIONS-RESEARCH-LLC" },
	{ 0x001BC5, 0x085000, 0x085FFF, "Oberon microsystems, Inc.", "OBERON-MICROSYSTEMS" },
	{ 0x001BC5, 0x086000, 0x086FFF, "CAST Group of Companies Inc.", "CAST-GROUP-OF-COMPANIES" },
	{ 0x001BC5, 0x087000, 0x087FFF, "Onnet Technologies And Innovations", "ONNET-TECHNOLOGIES-AND-INNOVATIONS" },
	{ 0x001BC5, 0x088000, 0x088FFF, "UAB Kitron", "UAB-KITRON" },
	{ 0x001BC5, 0x089000, 0x089FFF, "SIGNATURE CONTROL SYSTEMS, INC.", "SIGNATURE-CONTROL" },
	{ 0x001BC5, 0x08A000, 0x08AFFF, "Topicon", "TOPICON" },
	{ 0x001BC5, 0x08B000, 0x08BFFF, "Nistica", "NISTICA" },
	{ 0x001BC5, 0x08C000, 0x08CFFF, "Triax A/S", "TRIAX-A/S" },
	{ 0x001BC5, 0x08D000, 0x08DFFF, "EUREK SRL", "EUREK-SRL" },
	{ 0x001BC5, 0x08E000, 0x08EFFF, "TrendPoint Systems", "TRENDPOINT" },
	{ 0x001BC5, 0x08F000, 0x08FFFF, "Unilever R&amp;D", "UNILEVER-R-AMP-D" },
	{ 0x001BC5, 0x090000, 0x090FFF, "Seven Solutions S.L", "SEVEN-SOLUTIONS-S-L" },
	{ 0x001BC5, 0x091000, 0x091FFF, "3green ApS", "3GREEN-APS" },
	{ 0x001BC5, 0x092000, 0x092FFF, "Arnouse Digital Devices, Corp.", "ARNOUSE-DIGITAL-DEVICES" },
	{ 0x001BC5, 0x093000, 0x093FFF, "Ambient Devices, Inc.", "AMBIENT-DEVICES" },
	{ 0x001BC5, 0x094000, 0x094FFF, "reelyActive", "REELYACTIVE" },
	{ 0x001BC5, 0x095000, 0x095FFF, "PREVAC sp. z o.o.", "PREVAC-SP-Z-O-O" },
	{ 0x001BC5, 0x096000, 0x096FFF, "Sanstreak Corp.", "SANSTREAK" },
	{ 0x001BC5, 0x097000, 0x097FFF, "Plexstar Inc.", "PLEXSTAR" },
	{ 0x001BC5, 0x098000, 0x098FFF, "Cubic Systems, Inc.", "CUBIC" },
	{ 0x001BC5, 0x099000, 0x099FFF, "UAB Kitron", "UAB-KITRON" },
	{ 0x001BC5, 0x09A000, 0x09AFFF, "Shenzhen Guang Lian Zhi Tong Limited", "SHENZHEN-GUANG-LIAN-ZHI-TONG" },
	{ 0x001BC5, 0x09B000, 0x09BFFF, "YIK Corporation", "YIK" },
	{ 0x001BC5, 0x09C000, 0x09CFFF, "S.I.C.E.S. srl", "S-I-C-E-S-SRL" },
	{ 0x001BC5, 0x09D000, 0x09DFFF, "Navitar Inc", "NAVITAR" },
	{ 0x001BC5, 0x09E000, 0x09EFFF, "K+K Messtechnik GmbH", "K+K-MESSTECHNIK" },
	{ 0x001BC5, 0x09F000, 0x09FFFF, "ENTE Sp. z o.o.", "ENTE-SP-Z-O-O" },
	{ 0x001BC5, 0x0A0000, 0x0A0FFF, "HomerSoft sp. z o.o.", "HOMERSOFT-SP-Z-O-O" },
	{ 0x001BC5, 0x0A1000, 0x0A1FFF, "Hangzhou Zhiping Technology Co., Ltd.", "HANGZHOU-ZHIPING" },
	{ 0x001BC5, 0x0A2000, 0x0A2FFF, "Hettich Benelux", "HETTICH-BENELUX" },
	{ 0x001BC5, 0x0A3000, 0x0A3FFF, "P A Network Laboratory Co.,Ltd", "P-A-NETWORK-LABORATORY" },
	{ 0x001BC5, 0x0A4000, 0x0A4FFF, "RADMOR S.A.", "RADMOR" },
	{ 0x001BC5, 0x0A5000, 0x0A5FFF, "Tesla Controls", "TESLA-CONTROLS" },
	{ 0x001BC5, 0x0A6000, 0x0A6FFF, "Balter Security GmbH", "BALTER-SECURITY" },
	{ 0x001BC5, 0x0A7000, 0x0A7FFF, "L.G.L. Electronics S.p.a.", "L-G-L-ELECTRONICS-S-P-A" },
	{ 0x001BC5, 0x0A8000, 0x0A8FFF, "Link Precision", "LINK-PRECISION" },
	{ 0x001BC5, 0x0A9000, 0x0A9FFF, "Elektrometal SA", "ELEKTROMETAL" },
	{ 0x001BC5, 0x0AA000, 0x0AAFFF, "Senceive Ltd", "SENCEIVE" },
	{ 0x001BC5, 0x0AB000, 0x0ABFFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x0AC000, 0x0ACFFF, "AVnu Alliance", "AVNU-ALLIANCE" },
	{ 0x001BC5, 0x0AD000, 0x0ADFFF, "Tierra Japan Co.,Ltd", "TIERRA-JAPAN" },
	{ 0x001BC5, 0x0AE000, 0x0AEFFF, "Techlan Reti s.r.l.", "TECHLAN-RETI-S-R-L" },
	{ 0x001BC5, 0x0AF000, 0x0AFFFF, "Enerwise Solutions Ltd.", "ENERWISE-SOLUTIONS" },
	{ 0x001BC5, 0x0B0000, 0x0B0FFF, "J-D.COM", "J-D-COM" },
	{ 0x001BC5, 0x0B1000, 0x0B1FFF, "Roslen Eco-Networking Products", "ROSLEN-ECO-NETWORKING-PRODUCTS" },
	{ 0x001BC5, 0x0B2000, 0x0B2FFF, "SKODA electric a.s.", "SKODA-ELECTRIC-A-S" },
	{ 0x001BC5, 0x0B3000, 0x0B3FFF, "FSM Solutions Limited", "FSM-SOLUTIONS" },
	{ 0x001BC5, 0x0B4000, 0x0B4FFF, "COBAN SRL", "COBAN-SRL" },
	{ 0x001BC5, 0x0B5000, 0x0B5FFF, "Exibea AB", "EXIBEA-AB" },
	{ 0x001BC5, 0x0B6000, 0x0B6FFF, "Veilux inc.", "VEILUX" },
	{ 0x001BC5, 0x0B7000, 0x0B7FFF, "Autelis, LLC", "AUTELIS-LLC" },
	{ 0x001BC5, 0x0B8000, 0x0B8FFF, "PRIVATE", "PRIVATE" },
	{ 0x001BC5, 0x0B9000, 0x0B9FFF, "Denki Kogyo Company, Limited", "DENKI-KOGYO-COMPANY" },
	{ 0x001BC5, 0x0BA000, 0x0BAFFF, "NT MICROSYSTEMS", "NT-MICROSYSTEMS" },
	{ 0x001BC5, 0x0BB000, 0x0BBFFF, "Triax A/S", "TRIAX-A/S" },
	{ 0x001BC5, 0x0BC000, 0x0BCFFF, "kuwatec, Inc.", "KUWATEC" },
	{ 0x001BC5, 0x0BD000, 0x0BDFFF, "Bridge Diagnostics, Inc.", "BRIDGE-DIAGNOSTICS" },
	{ 0x001BC5, 0x0BE000, 0x0BEFFF, "YESpay International Ltd", "YESPAY" },
	{ 0x001BC5, 0x0BF000, 0x0BFFFF, "TN Core Co.,Ltd.", "TN-CORE" },
	{ 0x001BC5, 0x0C0000, 0x0C0FFF, "Digital Loggers, Inc.", "DIGITAL-LOGGERS" },
	{ 0x001BC5, 0x0C1000, 0x0C1FFF, "EREE Electronique", "EREE-ELECTRONIQUE" },
	{ 0x001BC5, 0x0C2000, 0x0C2FFF, "TechSolutions A/S", "TECHSOLUTIONS-A/S" },
	{ 0x001BC5, 0x0C3000, 0x0C3FFF, "inomatic GmbH", "INOMATIC" },
	{ 0x001BC5, 0x0C4000, 0x0C4FFF, "ELDES", "ELDES" },
	{ 0x001BC5, 0x0C5000, 0x0C5FFF, "Gill Instruments Ltd", "GILL-INSTRUMENTS" },
	{ 0x001BC5, 0x0C6000, 0x0C6FFF, "Connode", "CONNODE" },
	{ 0x001BC5, 0x0C7000, 0x0C7FFF, "WIZZILAB SAS", "WIZZILAB-SAS" },
	{ 0x001BC5, 0x0C8000, 0x0C8FFF, "Dialine", "DIALINE" },
	{ 0x001BC5, 0x0C9000, 0x0C9FFF, "UAB Kitron", "UAB-KITRON" },
	{ 0x70B3D5, 0xFFE000, 0xFFEFFF, "PRIVATE", "PRIVATE" },
	{ 0x70B3D5, 0x062000, 0x062FFF, "RM Michaelides Software & Elektronik GmbH", "RM-MICHAELIDES-SOFTWARE-ELEKTRONIK" },
	{ 0x70B3D5, 0xFFF000, 0xFFFFFF, "PRIVATE", "PRIVATE" },
	{ 0x70B3D5, 0xE58000, 0xE58FFF, "Thurlby Thandar Instruments LTD", "THURLBY-THANDAR-INSTRUMENTS" },
	{ 0x70B3D5, 0xD9E000, 0xD9EFFF, "GRUPO EPELSA S.L.", "GRUPO-EPELSA-S-L" },
	{ 0x70B3D5, 0xCE7000, 0xCE7FFF, "June Automation Singapore Pte. Ltd.", "JUNE-AUTOMATION-SINGAPORE-PTE" },
	{ 0x70B3D5, 0x3DE000, 0x3DEFFF, "ELOMAC Elektronik GmbH", "ELOMAC-ELEKTRONIK" },
	{ 0x70B3D5, 0x182000, 0x182FFF, "Kitron UAB", "KITRON-UAB" },
	{ 0x70B3D5, 0xB3D000, 0xB3DFFF, "Inras GmbH", "INRAS" },
	{ 0x70B3D5, 0x6F3000, 0x6F3FFF, "iungo", "IUNGO" },
	{ 0x70B3D5, 0xEDC000, 0xEDCFFF, "J.D. Koftinoff Software, Ltd.", "J-D-KOFTINOFF-SOFTWARE" },
	{ 0x70B3D5, 0x5EA000, 0x5EAFFF, "KYS,INC", "KYS" },
	{ 0x70B3D5, 0xEF9000, 0xEF9FFF, "Critical Link", "CRITICAL-LINK" },
	{ 0x70B3D5, 0xC61000, 0xC61FFF, "JC HUNTER TECHNOLOGIES", "JC-HUNTER-TECHNOLOGIES" },
	{ 0x70B3D5, 0xEDD000, 0xEDDFFF, "Solar Network & Partners", "SOLAR-NETWORK-PARTNERS" },
	{ 0x70B3D5, 0x48D000, 0x48DFFF, "OMEGA BILANCE SRL SOCIETA' UNIPERSONALE", "OMEGA-BILANCE-SRL-SOCIETA-UNIPERSONALE" },
	{ 0x70B3D5, 0xF62000, 0xF62FFF, "FRS GmbH & Co. KG", "FRS" },
	{ 0x70B3D5, 0xB82000, 0xB82FFF, "Lookout Portable Security", "LOOKOUT-PORTABLE-SECURITY" },
	{ 0x70B3D5, 0x0A9000, 0x0A9FFF, "ProConnections, Inc.", "PROCONNECTIONS" },
	{ 0x70B3D5, 0x220000, 0x220FFF, "PRIVATE", "PRIVATE" },
	{ 0x70B3D5, 0x3ED000, 0x3EDFFF, "Ultra Electronics Sonar System Division", "ULTRA-ELECTRONICS-SONAR-SYSTEM-DIVISION" },
	{ 0x70B3D5, 0xE28000, 0xE28FFF, "iotec GmbH", "IOTEC" },
	{ 0x70B3D5, 0x3C2000, 0x3C2FFF, "Cellular Specialties, Inc.", "CELLULAR-SPECIALTIES" },
	{ 0x70B3D5, 0xA5B000, 0xA5BFFF, "Christ Elektronik GmbH", "CHRIST-ELEKTRONIK" },
	{ 0x70B3D5, 0xD8B000, 0xD8BFFF, "Lenoxi Automation s.r.o.", "LENOXI-AUTOMATION-S-R-O" },
	{ 0x70B3D5, 0x39A000, 0x39AFFF, "Videotrend srl", "VIDEOTREND-SRL" },
	{ 0x70B3D5, 0xF63000, 0xF63FFF, "Ars Products", "ARS-PRODUCTS" },
	{ 0x70B3D5, 0x104000, 0x104FFF, "Plum sp. z o.o", "PLUM-SP-Z-O-O" },
	{ 0x70B3D5, 0x0AA000, 0x0AAFFF, "Wanco Inc", "WANCO" },
	{ 0x70B3D5, 0xB8D000, 0xB8DFFF, "JungwooEng Co., Ltd", "JUNGWOOENG" },
	{ 0x70B3D5, 0x994000, 0x994FFF, "KeFF Networks", "KEFF-NETWORKS" },
	{ 0x70B3D5, 0xCFF000, 0xCFFFFF, "DTECH Labs, Inc.", "DTECH-LABS" },
	{ 0x70B3D5, 0x0E0000, 0x0E0FFF, "PLCiS", "PLCIS" },
	{ 0x70B3D5, 0x959000, 0x959FFF, "Zulex International Co.,Ltd.", "ZULEX" },
	{ 0x70B3D5, 0xAE9000, 0xAE9FFF, "Cari Electronic", "CARI" },
	{ 0x70B3D5, 0x6D3000, 0x6D3FFF, "DEUTA-WERKE GmbH", "DEUTA-WERKE" },
	{ 0x70B3D5, 0x139000, 0x139FFF, "Tunstall A/S", "TUNSTALL-A/S" },
	{ 0x70B3D5, 0x908000, 0x908FFF, "Accusonic", "ACCUSONIC" },
	{ 0x70B3D5, 0x871000, 0x871FFF, "Oso Technologies", "OSO-TECHNOLOGIES" },
	{ 0x70B3D5, 0x814000, 0x814FFF, "Ingenieurbuero SOMTRONIK", "INGENIEURBUERO-SOMTRONIK" },
	{ 0x70B3D5, 0x183000, 0x183FFF, "Evco S.p.a.", "EVCO-S-P-A" },
	{ 0x70B3D5, 0x28F000, 0x28FFFF, "Overline Systems", "OVERLINE" },
	{ 0x70B3D5, 0x6B6000, 0x6B6FFF, "INRADIOS GmbH", "INRADIOS" },
	{ 0x70B3D5, 0x29D000, 0x29DFFF, "XTech2 SIA", "XTECH2-SIA" },
	{ 0x70B3D5, 0x109000, 0x109FFF, "DiTEST Fahrzeugdiagnose GmbH", "DITEST-FAHRZEUGDIAGNOSE" },
	{ 0x70B3D5, 0x184000, 0x184FFF, "XV360 Optical Information Systems Ltd.", "XV360-OPTICAL-INFORMATION" },
	{ 0x70B3D5, 0x35C000, 0x35CFFF, "ACS electronics srl", "ACS-ELECTRONICS-SRL" },
	{ 0x70B3D5, 0x40A000, 0x40AFFF, "Monroe Electronics, Inc.", "MONROE-ELECTRONICS" },
	{ 0x70B3D5, 0x190000, 0x190FFF, "Fantom Wireless, Inc.", "FANTOM-WIRELESS" },
	{ 0x70B3D5, 0x308000, 0x308FFF, "DSD MICROTECHNOLOGY,INC.", "DSD-MICROTECHNOLOGY" },
	{ 0x70B3D5, 0x9F4000, 0x9F4FFF, "Tband srl", "TBAND-SRL" },
	{ 0x70B3D5, 0xECD000, 0xECDFFF, "SBS-Feintechnik GmbH & Co. KG", "SBS-FEINTECHNIK" },
	{ 0x70B3D5, 0x918000, 0x918FFF, "Glova Rail A/S", "GLOVA-RAIL-A/S" },
	{ 0x70B3D5, 0x42F000, 0x42FFFF, "SINTOKOGIO, LTD", "SINTOKOGIO" },
	{ 0x70B3D5, 0xC8D000, 0xC8DFFF, "KST Technology", "KST" },
	{ 0x70B3D5, 0x702000, 0x702FFF, "Sensor Highway Ltd", "SENSOR-HIGHWAY" },
	{ 0x70B3D5, 0x044000, 0x044FFF, "Don Electronics Ltd", "DON-ELECTRONICS" },
	{ 0x70B3D5, 0xDDD000, 0xDDDFFF, "BIO RAD LABORATORIES", "BIO-RAD-LABORATORIES" },
	{ 0x70B3D5, 0xC2C000, 0xC2CFFF, "Dromont S.p.A.", "DROMONT-S-P-A" },
	{ 0x70B3D5, 0xFD1000, 0xFD1FFF, "RedRat Ltd", "REDRAT" },
	{ 0x70B3D5, 0x5A8000, 0x5A8FFF, "Farmobile", "FARMOBILE" },
	{ 0x70B3D5, 0x5E8000, 0x5E8FFF, "VITEC", "VITEC" },
	{ 0x70B3D5, 0x0FB000, 0x0FBFFF, "Cygnus LLC", "CYGNUS-LLC" },
	{ 0x70B3D5, 0xF38000, 0xF38FFF, "Scanvaegt Nordic A/S", "SCANVAEGT-NORDIC-A/S" },
	{ 0x70B3D5, 0x8B1000, 0x8B1FFF, "M-Tech Innovations Ltd", "M-TECH-INNOVATIONS" },
	{ 0x70B3D5, 0x9A7000, 0x9A7FFF, "Honeywell", "HONEYWELL" },
	{ 0x70B3D5, 0x4C8000, 0x4C8FFF, "Hosokawa Micron Powder Systems", "HOSOKAWA-MICRON-POWDER" },
	{ 0x70B3D5, 0xB8A000, 0xB8AFFF, "Nexus Tech. VN", "NEXUS-TECH-VN" },
	{ 0x70B3D5, 0x3A8000, 0x3A8FFF, "JamHub Corp.", "JAMHUB" },
	{ 0x70B3D5, 0x090000, 0x090FFF, "POWERCRAFT ELECTRONICS PVT. LTD.", "POWERCRAFT-ELECTRONICS-PVT" },
	{ 0x70B3D5, 0x3F1000, 0x3F1FFF, "Olympus NDT Canada", "OLYMPUS-NDT-CANADA" },
	{ 0x70B3D5, 0xCE9000, 0xCE9FFF, "KINEMETRICS", "KINEMETRICS" },
	{ 0x70B3D5, 0xA0B000, 0xA0BFFF, "ambiHome GmbH", "AMBIHOME" },
	{ 0x70B3D5, 0x1AC000, 0x1ACFFF, "SVP Broadcast Microwave S.L.", "SVP-BROADCAST-MICROWAVE-S-L" },
	{ 0x70B3D5, 0xD86000, 0xD86FFF, "WPGSYS Pte Ltd", "WPGSYS-PTE" },
	{ 0x70B3D5, 0x625000, 0x625FFF, "VX Instruments GmbH", "VX-INSTRUMENTS" },
	{ 0x70B3D5, 0xD4E000, 0xD4EFFF, "FLSmidth", "FLSMIDTH" },
	{ 0x70B3D5, 0xA0E000, 0xA0EFFF, "Vetaphone A/S", "VETAPHONE-A/S" },
	{ 0x70B3D5, 0xE08000, 0xE08FFF, "Olssen", "OLSSEN" },
	{ 0x70B3D5, 0x433000, 0x433FFF, "Flexsolution APS", "FLEXSOLUTION-APS" },
	{ 0x70B3D5, 0xF34000, 0xF34FFF, "MacGray Services", "MACGRAY-SERVICES" },
	{ 0x70B3D5, 0xF61000, 0xF61FFF, "Power Diagnostic Service", "POWER-DIAGNOSTIC-SERVICE" },
	{ 0x70B3D5, 0x4C1000, 0x4C1FFF, "QUERCUS TECHNOLOGIES, S. L.", "QUERCUS-TECHNOLOGIES-S-L" },
	{ 0x70B3D5, 0xFB0000, 0xFB0FFF, "Rohde&Schwarz Topex SA", "ROHDE-SCHWARZ-TOPEX" },
	{ 0x70B3D5, 0x077000, 0x077FFF, "InAccess Networks SA", "INACCESS-NETWORKS" },
	{ 0x70B3D5, 0x80F000, 0x80FFFF, "Quickware Eng & Des LLC", "QUICKWARE-ENG-DES-LLC" },
	{ 0x70B3D5, 0x0F0000, 0x0F0FFF, "Avionica", "AVIONICA" },
	{ 0x70B3D5, 0xC27000, 0xC27FFF, "GENERAL DYNAMICS C4 SYSTEMS", "GENERAL-DYNAMICS-C4" },
	{ 0x70B3D5, 0x51D000, 0x51DFFF, "Tecnint HTE Srl", "TECNINT-HTE-SRL" },
	{ 0x70B3D5, 0x51E000, 0x51EFFF, "Fundación Cardiovascular de Colombia", "FUNDACIóN-CARDIOVASCULAR-DE-COLOMBIA" },
	{ 0x70B3D5, 0x61F000, 0x61FFFF, "Labotect Labor-Technik-Göttingen GmbH", "LABOTECT-LABOR-TECHNIK-GOETTINGEN" },
	{ 0x70B3D5, 0xEB0000, 0xEB0FFF, "Nautel Limted", "NAUTEL-LIMTED" },
	{ 0x70B3D5, 0xB2A000, 0xB2AFFF, "Myro Control, LLC", "MYRO-CONTROL-LLC" },
	{ 0x70B3D5, 0x79A000, 0x79AFFF, "Innerspec Technologies Inc.", "INNERSPEC-TECHNOLOGIES" },
	{ 0x70B3D5, 0xBB2000, 0xBB2FFF, "Mettler-Toledo Hi-Speed", "METTLER-TOLEDO-HI-SPEED" },
	{ 0x70B3D5, 0xB15000, 0xB15FFF, "Eta Beta Srl", "ETA-BETA-SRL" },
	{ 0x70B3D5, 0xD47000, 0xD47FFF, "YotaScope Technologies Co., Ltd.", "YOTASCOPE-TECHNOLOGIES" },
	{ 0x70B3D5, 0x35F000, 0x35FFFF, "Aplex Technology Inc.", "APLEX" },
	{ 0x70B3D5, 0x052000, 0x052FFF, "Sudo Premium Engineering", "SUDO-PREMIUM-ENGINEERING" },
	{ 0x70B3D5, 0xA2F000, 0xA2FFFF, "Botek Systems AB", "BOTEK-AB" },
	{ 0x70B3D5, 0x96F000, 0x96FFFF, "4CAM GmbH", "4CAM" },
	{ 0x70B3D5, 0x8CE000, 0x8CEFFF, "CORES Corporation", "CORES" },
	{ 0x70B3D5, 0x346000, 0x346FFF, "Ultamation Limited", "ULTAMATION" },
	{ 0x70B3D5, 0x23C000, 0x23CFFF, "Quasonix, LLC", "QUASONIX-LLC" },
	{ 0x70B3D5, 0xADD000, 0xADDFFF, "GHL Systems Berhad", "GHL-BERHAD" },
	{ 0x70B3D5, 0x6F6000, 0x6F6FFF, "Acco Brands Europe", "ACCO-BRANDS-EUROPE" },
	{ 0x70B3D5, 0xD8F000, 0xD8FFFF, "Molu Technology Inc., LTD.", "MOLU" },
	{ 0x70B3D5, 0x3E1000, 0x3E1FFF, "Barnstormer Softworks", "BARNSTORMER-SOFTWORKS" },
	{ 0x70B3D5, 0x5B5000, 0x5B5FFF, "Lehigh Electric Products Co", "LEHIGH-ELECTRIC-PRODUCTS" },
	{ 0x70B3D5, 0xC58000, 0xC58FFF, "RMI Laser LLC", "RMI-LASER-LLC" },
	{ 0x70B3D5, 0x507000, 0x507FFF, "Human Oriented Technology, Inc.", "HUMAN-ORIENTED" },
	{ 0x70B3D5, 0xCB7000, 0xCB7FFF, "HKC Limited", "HKC" },
	{ 0x70B3D5, 0xEF2000, 0xEF2FFF, "Kongsberg Intergrated Tactical Systems", "KONGSBERG-INTERGRATED-TACTICAL" },
	{ 0x70B3D5, 0xEE4000, 0xEE4FFF, "O-Net Automation Technology (Shenzhen)Limited", "O-NET-AUTOMATION-SHENZHEN" },
	{ 0x70B3D5, 0x60B000, 0x60BFFF, "Edgeware AB", "EDGEWARE-AB" },
	{ 0x70B3D5, 0x2F0000, 0x2F0FFF, "Clock-O-Matic", "CLOCK-O-MATIC" },
	{ 0x70B3D5, 0x60C000, 0x60CFFF, "IST ElektronikgesmbH", "IST-ELEKTRONIKGESMBH" },
	{ 0x70B3D5, 0x7A9000, 0x7A9FFF, "adidas AG", "ADIDAS" },
	{ 0x70B3D5, 0x936000, 0x936FFF, "FARO TECHNOLOGIES, INC.", "FARO-TECHNOLOGIES" },
	{ 0x70B3D5, 0xFD3000, 0xFD3FFF, "AKIS technologies", "AKIS-TECHNOLOGIES" },
	{ 0x70B3D5, 0xC81000, 0xC81FFF, "DSP DESIGN", "DSP-DESIGN" },
	{ 0x70B3D5, 0xFA1000, 0xFA1FFF, "BBI Engineering, Inc.", "BBI-ENGINEERING" },
	{ 0x70B3D5, 0xE53000, 0xE53FFF, "MI INC.", "MI" },
	{ 0x70B3D5, 0xE74000, 0xE74FFF, "Exfrontier Co., Ltd.", "EXFRONTIER" },
	{ 0x70B3D5, 0xEFA000, 0xEFAFFF, "NextEra Energy Resources, LLC", "NEXTERA-ENERGY-RESOURCES-LLC" },
	{ 0x70B3D5, 0x2D4000, 0x2D4FFF, "CT Company", "CT-COMPANY" },
	{ 0x70B3D5, 0xC96000, 0xC96FFF, "UNI DIMENXI SDN BHD", "UNI-DIMENXI-SDN-BHD" },
	{ 0x70B3D5, 0x39B000, 0x39BFFF, "IROC AB", "IROC-AB" },
	{ 0x70B3D5, 0x28E000, 0x28EFFF, "TEX COMPUTER SRL", "TEX-SRL" },
	{ 0x70B3D5, 0x655000, 0x655FFF, "AOT System GmbH", "AOT-SYSTEM" },
	{ 0x70B3D5, 0x5AA000, 0x5AAFFF, "Chugoku Electric Manufacturing Co.,Inc", "CHUGOKU-ELECTRIC-MANUFACTURING" },
	{ 0x70B3D5, 0x7E7000, 0x7E7FFF, "Atessa, Inc.", "ATESSA" },
	{ 0x70B3D5, 0xE4A000, 0xE4AFFF, "ICP NewTech Ltd", "ICP-NEWTECH" },
	{ 0x70B3D5, 0xE07000, 0xE07FFF, "Baader Planetarium GmbH", "BAADER-PLANETARIUM" },
	{ 0x70B3D5, 0x0D6000, 0x0D6FFF, "TATTILE SRL", "TATTILE-SRL" },
	{ 0x70B3D5, 0xB39000, 0xB39FFF, "MB Connect Line GmbH", "MB-CONNECT-LINE" },
	{ 0x70B3D5, 0x2A5000, 0x2A5FFF, "Taitotekniikka", "TAITOTEKNIIKKA" },
	{ 0x70B3D5, 0xC24000, 0xC24FFF, "Elbit Systems of America", "ELBIT-OF-AMERICA" },
	{ 0x70B3D5, 0x564000, 0x564FFF, "christmann informationstechnik + medien GmbH & Co. KG", "CHRISTMANN-INFORMATIONSTECHNIK-+-MEDIEN" },
	{ 0x70B3D5, 0xC78000, 0xC78FFF, "NETA Elektronik AS", "NETA-ELEKTRONIK-AS" },
	{ 0x70B3D5, 0xF2A000, 0xF2AFFF, "WIBOND Informationssysteme GmbH", "WIBOND-INFORMATIONSSYSTEME" },
	{ 0x70B3D5, 0x86D000, 0x86DFFF, "Census Digital Incorporated", "CENSUS-DIGITAL-INCORPORATED" },
	{ 0x70B3D5, 0xAC8000, 0xAC8FFF, "Heartland.Data Inc.", "HEARTLAND-DATA" },
	{ 0x70B3D5, 0x634000, 0x634FFF, "idaqs Co.,Ltd.", "IDAQS" },
	{ 0x70B3D5, 0x010000, 0x010FFF, "Hanwa Electronic Ind.Co.,Ltd.", "HANWA-IND" },
	{ 0x70B3D5, 0x2DA000, 0x2DAFFF, "Skywave Networks Private Limited", "SKYWAVE-NETWORKS-PRIVATE" },
	{ 0x70B3D5, 0xBBD000, 0xBBDFFF, "Providius Corp", "PROVIDIUS" },
	{ 0x70B3D5, 0xCBC000, 0xCBCFFF, "Procon Electronics Pty Ltd", "PROCON-ELECTRONICS-PTY" },
	{ 0x70B3D5, 0x305000, 0x305FFF, "CAITRON Industrial Solutions GmbH", "CAITRON-INDUSTRIAL-SOLUTIONS" },
	{ 0x70B3D5, 0x8AB000, 0x8ABFFF, "EMAC, Inc.", "EMAC" },
	{ 0x70B3D5, 0x819000, 0x819FFF, "«Intellect module» LLC", "«INTELLECT-MODULE»-LLC" },
	{ 0x70B3D5, 0x029000, 0x029FFF, "Marimo electronics Co.,Ltd.", "MARIMO-ELECTRONICS" },
	{ 0x70B3D5, 0x2FD000, 0x2FDFFF, "Special Projects Group, Inc", "SPECIAL-PROJECTS-GROUP" },
	{ 0x70B3D5, 0xC6A000, 0xC6AFFF, "PRIVATE", "PRIVATE" },
	{ 0x70B3D5, 0xA7A000, 0xA7AFFF, "Fluid Management Technology", "FLUID-MANAGEMENT" },
	{ 0x70B3D5, 0x83B000, 0x83BFFF, "Telefonix Incorporated", "TELEFONIX-INCORPORATED" },
	{ 0x70B3D5, 0x204000, 0x204FFF, "TWC", "TWC" },
	{ 0x70B3D5, 0x099000, 0x099FFF, "Schwer+Kopka GmbH", "SCHWER+KOPKA" },
	{ 0x70B3D5, 0x54E000, 0x54EFFF, "RFL Electronics, Inc.", "RFL-ELECTRONICS" },
	{ 0x70B3D5, 0xB16000, 0xB16FFF, "XI'AN SHENMING ELECTRON TECHNOLOGY CO.,LTD", "XI-AN-SHENMING-ELECTRON" },
	{ 0x70B3D5, 0xECF000, 0xECFFFF, "Ipitek", "IPITEK" },
	{ 0x70B3D5, 0xB33000, 0xB33FFF, "Aplex Technology Inc.", "APLEX" },
	{ 0x70B3D5, 0xA40000, 0xA40FFF, "STRACK LIFT AUTOMATION GmbH", "STRACK-LIFT-AUTOMATION" },
	{ 0x70B3D5, 0xDEC000, 0xDECFFF, "Condev-Automation GmbH", "CONDEV-AUTOMATION" },
	{ 0x70B3D5, 0x016000, 0x016FFF, "Guardian Controls International Ltd", "GUARDIAN-CONTROLS" },
	{ 0x70B3D5, 0x710000, 0x710FFF, "Guardian Controls International Ltd", "GUARDIAN-CONTROLS" },
	{ 0x70B3D5, 0xAEE000, 0xAEEFFF, "DiTEST Fahrzeugdiagnose GmbH", "DITEST-FAHRZEUGDIAGNOSE" },
	{ 0x70B3D5, 0xF68000, 0xF68FFF, "AL ZAJEL MODERN TELECOMM", "AL-ZAJEL-MODERN-TELECOMM" },
	{ 0x70B3D5, 0x3E5000, 0x3E5FFF, "ATEME", "ATEME" },
	{ 0x70B3D5, 0xE27000, 0xE27FFF, "Woodside Electronics", "WOODSIDE-ELECTRONICS" },
	{ 0x70B3D5, 0xFC5000, 0xFC5FFF, "Eltwin A/S", "ELTWIN-A/S" },
	{ 0x70B3D5, 0x559000, 0x559FFF, "Eagle Mountain Technology", "EAGLE-MOUNTAIN" },
	{ 0x70B3D5, 0x33C000, 0x33CFFF, "Videri Inc.", "VIDERI" },
	{ 0x70B3D5, 0x587000, 0x587FFF, "INCAA Computers", "INCAA-COMPUTERS" },
	{ 0x70B3D5, 0xB08000, 0xB08FFF, "Secuinfo Co. Ltd", "SECUINFO" },
	{ 0x70B3D5, 0x01D000, 0x01DFFF, "Weigl Elektronik & Mediaprojekte", "WEIGL-ELEKTRONIK-MEDIAPROJEKTE" },
	{ 0x70B3D5, 0xBDA000, 0xBDAFFF, "5-D Systems, Inc.", "5-D" },
	{ 0x70B3D5, 0xDC5000, 0xDC5FFF, "Excel Medical Electronics LLC", "EXCEL-MEDICAL-ELECTRONICS-LLC" },
	{ 0x70B3D5, 0x6D9000, 0x6D9FFF, "VECTARE Inc", "VECTARE" },
	{ 0x70B3D5, 0xFDA000, 0xFDAFFF, "ACD Elektronik GmbH", "ACD-ELEKTRONIK" },
	{ 0x70B3D5, 0x751000, 0x751FFF, "GNF", "GNF" },
	{ 0x70B3D5, 0xBBE000, 0xBBEFFF, "Sunrise Systems Electronics Co. Inc.", "SUNRISE-ELECTRONICS" },
	{ 0x70B3D5, 0x45E000, 0x45EFFF, "eSOL Co.,Ltd.", "ESOL" },
	{ 0x70B3D5, 0xB88000, 0xB88FFF, "ARP Corporation", "ARP" },
	{ 0x70B3D5, 0xEF3000, 0xEF3FFF, "octoScope", "OCTOSCOPE" },
	{ 0x70B3D5, 0xE4C000, 0xE4CFFF, "IAI-Israel Aerospace Industries MBT", "IAI-ISRAEL-AEROSPACE-INDUSTRIES-MBT" },
	{ 0x70B3D5, 0x43D000, 0x43DFFF, "Veryx Technologies Private Limited", "VERYX-TECHNOLOGIES-PRIVATE" },
	{ 0x70B3D5, 0xAB7000, 0xAB7FFF, "SIGLEAD INC", "SIGLEAD" },
	{ 0x70B3D5, 0x6F2000, 0x6F2FFF, "P&C Micro's Pty Ltd", "P-C-MICRO-S-PTY" },
	{ 0x70B3D5, 0xA15000, 0xA15FFF, "Intercore GmbH", "INTERCORE" },
	{ 0x70B3D5, 0xBCA000, 0xBCAFFF, "Deymed Diagnostic", "DEYMED-DIAGNOSTIC" },
	{ 0x70B3D5, 0x362000, 0x362FFF, "Asiga", "ASIGA" },
	{ 0x70B3D5, 0x54D000, 0x54DFFF, "Qingdao Haitian Weiye Automation Control System Co., Ltd", "QINGDAO-HAITIAN-WEIYE-AUTOMATION-CONTROL-SYSTEM" },
	{ 0x70B3D5, 0xE26000, 0xE26FFF, "FEITIAN CO.,LTD.", "FEITIAN" },
	{ 0x70B3D5, 0xE99000, 0xE99FFF, "Advitronics telecom bv", "ADVITRONICS-TELECOM" },
	{ 0x70B3D5, 0xB8C000, 0xB8CFFF, "ePOINT Embedded Computing Limited", "EPOINT-EMBEDDED-COMPUTING" },
	{ 0x70B3D5, 0xE9A000, 0xE9AFFF, "Meta Computing Services, Corp", "META-COMPUTING-SERVICES" },
	{ 0x70B3D5, 0xB3C000, 0xB3CFFF, "DORLET SAU", "DORLET-SAU" },
	{ 0x70B3D5, 0xD1E000, 0xD1EFFF, "Houston Radar LLC", "HOUSTON-RADAR-LLC" },
	{ 0x70B3D5, 0xABC000, 0xABCFFF, "BKM-Micronic Richtfunkanlagen GmbH", "BKM-MICRONIC-RICHTFUNKANLAGEN" },
	{ 0x70B3D5, 0x5F0000, 0x5F0FFF, "managee GmbH & Co KG", "MANAGEE" },
	{ 0x70B3D5, 0x956000, 0x956FFF, "AeroVision Avionics, Inc.", "AEROVISION-AVIONICS" },
	{ 0x70B3D5, 0x57B000, 0x57BFFF, "ELAMAKATO GmbH", "ELAMAKATO" },
	{ 0x70B3D5, 0x19C000, 0x19CFFF, "Kubu, Inc.", "KUBU" },
	{ 0x70B3D5, 0x03B000, 0x03BFFF, "SSL - Electrical Aerospace Ground Equipment Section", "SSL---ELECTRICAL-AEROSPACE-GROUND-EQUIPMENT-SECTION" },
	{ 0x70B3D5, 0x2E3000, 0x2E3FFF, "Meiknologic GmbH", "MEIKNOLOGIC" },
	{ 0x70B3D5, 0x755000, 0x755FFF, "LandmarkTech Systems Technology Co.,Ltd.", "LANDMARKTECH" },
	{ 0x70B3D5, 0x6E5000, 0x6E5FFF, "DEUTA-WERKE GmbH", "DEUTA-WERKE" },
	{ 0x70B3D5, 0x8F5000, 0x8F5FFF, "Stmovic", "STMOVIC" },
	{ 0x70B3D5, 0xABF000, 0xABFFFF, "AGR International", "AGR" },
	{ 0x70B3D5, 0x8DC000, 0x8DCFFF, "Niveo International BV", "NIVEO" },
	{ 0x70B3D5, 0x34A000, 0x34AFFF, "PAVO TASARIM ÜRETİM TİC A.Ş.", "PAVO-TASARIM-UERETİM-TİC-A-Ş" },
	{ 0x70B3D5, 0x95A000, 0x95AFFF, "Sigmann Elektronik GmbH", "SIGMANN-ELEKTRONIK" },
	{ 0x70B3D5, 0x323000, 0x323FFF, "TATTILE SRL", "TATTILE-SRL" },
	{ 0x70B3D5, 0x986000, 0x986FFF, "Aplex Technology Inc.", "APLEX" },
	{ 0x70B3D5, 0x3CE000, 0x3CEFFF, "Aditec GmbH", "ADITEC" },
	{ 0x70B3D5, 0x250000, 0x250FFF, "Datum Electronics Limited", "DATUM-ELECTRONICS" },
	{ 0x70B3D5, 0x0B3000, 0x0B3FFF, "Reonix Automation", "REONIX-AUTOMATION" },
	{ 0x70B3D5, 0x682000, 0x682FFF, "Rosslare Enterprises Limited", "ROSSLARE-ENTERPRISES" },
	{ 0x70B3D5, 0xA57000, 0xA57FFF, "PCSC", "PCSC" },
	{ 0x70B3D5, 0x058000, 0x058FFF, "Telink Semiconductor CO, Limtied, Taiwan", "TELINK-SEMICONDUCTOR-LIMTIED-TAIWAN" },
	{ 0x70B3D5, 0xEB2000, 0xEB2FFF, "Shooter Detection Systems", "SHOOTER-DETECTION" },
	{ 0x70B3D5, 0x709000, 0x709FFF, "AML", "AML" },
	{ 0x70B3D5, 0x20C000, 0x20CFFF, "Siemens Healthcare Diagnostics", "SIEMENS-HEALTHCARE-DIAGNOSTICS" },
	{ 0x70B3D5, 0xAA0000, 0xAA0FFF, "Simple Works, Inc.", "SIMPLE-WORKS" },
	{ 0x70B3D5, 0xA62000, 0xA62FFF, "Environexus", "ENVIRONEXUS" },
	{ 0x70B3D5, 0x025000, 0x025FFF, "Elsuhd Net Ltd Co.", "ELSUHD-NET" },
	{ 0x70B3D5, 0x36D000, 0x36DFFF, "Cyberteam Sp z o o", "CYBERTEAM-SP-Z-O-O" },
	{ 0x70B3D5, 0xCF1000, 0xCF1FFF, "LightDec GmbH & Co. KG", "LIGHTDEC" },
	{ 0x70B3D5, 0x82C000, 0x82CFFF, "NELS Ltd.", "NELS" },
	{ 0x70B3D5, 0x941000, 0x941FFF, "Triax A/S", "TRIAX-A/S" },
	{ 0x70B3D5, 0x55D000, 0x55DFFF, "LunaNexus Inc", "LUNANEXUS" },
	{ 0x70B3D5, 0x731000, 0x731FFF, "Phoniro Systems AB", "PHONIRO-AB" },
	{ 0x70B3D5, 0xDF3000, 0xDF3FFF, "SPC Bioclinicum", "SPC-BIOCLINICUM" },
	{ 0x70B3D5, 0x501000, 0x501FFF, "PEEK TRAFFIC", "PEEK-TRAFFIC" },
	{ 0x70B3D5, 0x3EF000, 0x3EFFFF, "Vtron Pty Ltd", "VTRON-PTY" },
	{ 0x70B3D5, 0x3DF000, 0x3DFFFF, "MultiDyne", "MULTIDYNE" },
	{ 0x70B3D5, 0xBC6000, 0xBC6FFF, "Hatteland Display AS", "HATTELAND-DISPLAY-AS" },
	{ 0x70B3D5, 0x0C0000, 0x0C0FFF, "Molu Technology Inc., LTD.", "MOLU" },
	{ 0x70B3D5, 0xAE2000, 0xAE2FFF, "Transas Marine International", "TRANSAS-MARINE" },
	{ 0x70B3D5, 0x708000, 0x708FFF, "IBM Research GmbH", "IBM-RESEARCH" },
	{ 0x70B3D5, 0xC43000, 0xC43FFF, "Future Skies", "FUTURE-SKIES" },
	{ 0x70B3D5, 0xF2B000, 0xF2BFFF, "SENSYS GmbH", "SENSYS" },
	{ 0x70B3D5, 0xC6D000, 0xC6DFFF, "Cyviz AS", "CYVIZ-AS" },
	{ 0x70B3D5, 0xDA1000, 0xDA1FFF, "Qprel srl", "QPREL-SRL" },
	{ 0x70B3D5, 0x85C000, 0x85CFFF, "Robot Pub Group", "ROBOT-PUB-GROUP" },
	{ 0x70B3D5, 0x22B000, 0x22BFFF, "VITEC", "VITEC" },
	{ 0x70B3D5, 0x1F5000, 0x1F5FFF, "Martec S.p.A.", "MARTEC-S-P-A" },
	{ 0x70B3D5, 0xE92000, 0xE92FFF, "FUJI DATA SYSTEM CO.,LTD.", "FUJI-DATA-SYSTEM" },
	{ 0x70B3D5, 0xF8C000, 0xF8CFFF, "EUROPEAN ADVANCED TECHNOLOGIES", "EUROPEAN-ADVANCED-TECHNOLOGIES" },
	{ 0x70B3D5, 0x08E000, 0x08EFFF, "Beijing CONvision Technology Co.,Ltd", "BEIJING-CONVISION" },
	{ 0x70B3D5, 0xBA4000, 0xBA4FFF, "EIWA GIKEN INC.", "EIWA-GIKEN" },
	{ 0x70B3D5, 0x57C000, 0x57CFFF, "Automata GmbH & Co. KG", "AUTOMATA" },
	{ 0x70B3D5, 0xD59000, 0xD59FFF, "WyreStorm Technologies", "WYRESTORM-TECHNOLOGIES" },
	{ 0x70B3D5, 0x6D6000, 0x6D6FFF, "KMtronic Ltd.", "KMTRONIC" },
	{ 0x70B3D5, 0x243000, 0x243FFF, "Rohde&Schwarz Topex SA", "ROHDE-SCHWARZ-TOPEX" },
	{ 0x70B3D5, 0x8E0000, 0x8E0FFF, "SOUDAX EQUIPEMENTS", "SOUDAX-EQUIPEMENTS" },
	{ 0x70B3D5, 0xFF3000, 0xFF3FFF, "Aplex Technology Inc.", "APLEX" },
	{ 0x70B3D5, 0xBEC000, 0xBECFFF, "Tokyo Communication Equipment MFG Co.,ltd.", "TOKYO-COMMUNICATION-EQUIPMENT-MFG" },
	{ 0x70B3D5, 0x112000, 0x112FFF, "DiTEST Fahrzeugdiagnose GmbH", "DITEST-FAHRZEUGDIAGNOSE" },
	{ 0x70B3D5, 0x8E1000, 0x8E1FFF, "WoKa-Elektronik GmbH", "WOKA-ELEKTRONIK" },
	{ 0x70B3D5, 0x3B8000, 0x3B8FFF, "nVideon, Inc.", "NVIDEON" },
	{ 0x70B3D5, 0xCDE000, 0xCDEFFF, "Multipure International", "MULTIPURE" },
	{ 0x70B3D5, 0x205000, 0x205FFF, "Esource Srl", "ESOURCE-SRL" },
	{ 0x70B3D5, 0x502000, 0x502FFF, "Glidewell Laboratories", "GLIDEWELL-LABORATORIES" },
	{ 0x70B3D5, 0x71E000, 0x71EFFF, "Motec Pty Ltd", "MOTEC-PTY" },
	{ 0x70B3D5, 0x091000, 0x091FFF, "eZeLink LLC", "EZELINK-LLC" },
	{ 0x70B3D5, 0xA6D000, 0xA6DFFF, "Metek Meteorologische Messtechnik GmbH", "METEK-METEOROLOGISCHE-MESSTECHNIK" },
	{ 0x70B3D5, 0xEC1000, 0xEC1FFF, "Xafax Nederland bv", "XAFAX-NEDERLAND" },
	{ 0x70B3D5, 0x0FF000, 0x0FFFFF, "INTERNET PROTOCOLO LOGICA SL", "INTERNET-PROTOCOLO-LOGICA-SL" },
	{ 0x70B3D5, 0x7B3000, 0x7B3FFF, "BroadSoft Inc", "BROADSOFT" },
	{ 0x70B3D5, 0x7D5000, 0x7D5FFF, "Power Dragon Development Limited", "POWER-DRAGON-DEVELOPMENT" },
	{ 0x70B3D5, 0x0AB000, 0x0ABFFF, "KST technology", "KST" },

};
